<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="eu" sourcelanguage="en">
  <context>
    <name>CmdMeshPartCrossSections</name>
    <message>
      <location filename="../../Command.cpp" line="269"/>
      <source>MeshPart</source>
      <translation>Amaraun-pieza</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="270"/>
      <source>Cross-sections...</source>
      <translation>Zeharkako sekzioak...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="271"/>
      <source>Cross-sections</source>
      <translation>Zeharkako sekzioak</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartCurveOnMesh</name>
    <message>
      <location filename="../../Command.cpp" line="305"/>
      <source>Mesh</source>
      <translation>Amarauna</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="306"/>
      <source>Curve on mesh...</source>
      <translation>Kurba amaraunean...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="307"/>
      <source>Creates an approximated curve on top of a mesh.
This command only works with a 'mesh' object.</source>
      <translation>Amaraun baten gainean hari egokitzen zaion gutxi gora beherako kurba bat sortzen du.
Komando honek 'amarauna' objektuetan soilik funtzionatzen du.</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartMesher</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <source>Mesh</source>
      <translation>Amarauna</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="59"/>
      <source>Create mesh from shape...</source>
      <translation>Sortu amarauna formatik...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="60"/>
      <source>Tessellate shape</source>
      <translation>Teselatu forma</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartSection</name>
    <message>
      <location filename="../../Command.cpp" line="185"/>
      <source>Mesh</source>
      <translation>Amarauna</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="186"/>
      <source>Create section from mesh and plane</source>
      <translation>Sortu sekzioa amaraunetik eta planotik</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="187"/>
      <source>Section</source>
      <translation>Sekzioa</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshPartTrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Mesh</source>
      <translation>Amarauna</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="84"/>
      <source>Trim mesh with a plane</source>
      <translation>Muxarratu amarauna plano batekin</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="85"/>
      <location filename="../../Command.cpp" line="86"/>
      <source>Trims a mesh with a plane</source>
      <translation>Amaraun bat muxarratzen du plano batekin</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="129"/>
      <source>Trim with plane</source>
      <translation>Ebaki planoarekin</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Section with plane</source>
      <translation>Sekzioa planoarekin</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CrossSections</name>
    <message>
      <location filename="../../CrossSections.ui" line="14"/>
      <source>Cross sections</source>
      <translation>Zeharkako sekzioak</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="20"/>
      <source>Guiding plane</source>
      <translation>Gida-planoa</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="26"/>
      <source>XY</source>
      <translation>XY</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="36"/>
      <source>XZ</source>
      <translation>XZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="43"/>
      <source>YZ</source>
      <translation>YZ</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="52"/>
      <source>Position:</source>
      <translation>Posizioa:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="71"/>
      <source>Sections</source>
      <translation>Sekzioak</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="83"/>
      <source>On both sides</source>
      <translation>Bi aldeetan</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="92"/>
      <source>Count</source>
      <translation>Zenbaketa</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="109"/>
      <source>Distance:</source>
      <translation>Distantzia:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="128"/>
      <source>Options</source>
      <translation>Aukerak</translation>
    </message>
    <message>
      <location filename="../../CrossSections.ui" line="134"/>
      <source>Connect edges if distance less than</source>
      <translation>Konektatu ertzak distantzia hau baino txikiagoa bada:</translation>
    </message>
    <message>
      <location filename="../../CrossSections.cpp" line="366"/>
      <source>Failure</source>
      <translation>Hutsegitea</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::CurveOnMeshHandler</name>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="364"/>
      <source>Create</source>
      <translation>Sortu</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="366"/>
      <source>Close wire</source>
      <translation>Itxi lerroa</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="368"/>
      <source>Clear</source>
      <translation>Garbitu</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="369"/>
      <source>Cancel</source>
      <translation>Utzi</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="615"/>
      <source>Wrong mesh picked</source>
      <translation>Amaraun okerra aukeratu da</translation>
    </message>
    <message>
      <location filename="../../CurveOnMesh.cpp" line="655"/>
      <source>No point was picked</source>
      <translation>Ez da punturik aukeratu</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::TaskCurveOnMesh</name>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="14"/>
      <source>Curve on mesh</source>
      <translation>Kurba amaraunean</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="23"/>
      <source>Press 'Start', then pick points on the mesh; when enough points have been set, right-click and choose 'Create'. Repeat this process to create more splines. Close this task panel to complete the operation.

This command only works with a 'mesh' object, not a regular face or surface. To convert an object to a mesh use the tools of the Mesh Workbench.</source>
      <translation>Sakatu 'Hasi', ondoren aukeratu amarauneko puntuak; nahiko puntu ezarri direnean, egin eskuineko klik eta aukeratu 'Sortu'. Errepikatu prozesu hori spline gehiago sortzeko. Itxi atazen panel hau eragiketa osatzeko.

Komando honek 'amarauna' objektuetan soilik funtzionatzen du, ez aurpegi edo gainazal erregularretan. Objektu bat amaraun bihurtzeko, erabili amaraunen lan-mahaiko tresnak.</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="38"/>
      <source>Wire</source>
      <translation>Alanbrea</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="44"/>
      <source>Snap tolerance to vertices</source>
      <translation>Erpinen atxikitze-tolerantzia</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="51"/>
      <source> px</source>
      <translation> px</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="61"/>
      <source>Split threshold</source>
      <translation>Zatiketa-atalasea</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="87"/>
      <source>Spline Approximation</source>
      <translation>Spline hurbilketa</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="96"/>
      <source>Tolerance to mesh</source>
      <translation>Amaraunarekiko tolerantzia</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="122"/>
      <source>Continuity</source>
      <translation>Jarraitutasuna</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="136"/>
      <source>Maximum curve degree</source>
      <translation>Kurba-gradu maximoa</translation>
    </message>
    <message>
      <location filename="../../TaskCurveOnMesh.ui" line="153"/>
      <source>Start</source>
      <translation>Hasi</translation>
    </message>
  </context>
  <context>
    <name>MeshPartGui::Tessellation</name>
    <message>
      <location filename="../../Tessellation.ui" line="14"/>
      <source>Tessellation</source>
      <translation>Teselazioa</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="20"/>
      <source>Meshing options</source>
      <translation>Amaraun-aukerak</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="30"/>
      <source>Standard</source>
      <translation>Estandarra</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="33"/>
      <source>Use the standard mesher</source>
      <translation>Erabili amaraun-sortzaile estandarra</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="41"/>
      <source>Surface deviation:</source>
      <translation>Gainazalaren desbideratzea:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="48"/>
      <source>Maximal linear deflection of a mesh section from the surface of the object</source>
      <translation>Amaraun-sekzio baten makurdura lineal maximoa objektuaren gainazaletik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="67"/>
      <source>Angular deviation:</source>
      <translation>Desbideratze angeluarra:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="74"/>
      <source>Maximal angular deflection of a mesh section to the next section</source>
      <translation>Amaraun-sekzio baten makurdura angeluar maximoa hurrengo sekziotik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="98"/>
      <source>The maximal linear deviation of a mesh segment will be the specified
Surface deviation multiplied by the length of the current mesh segment (edge)</source>
      <translation>Amaraun segmentu baten desbideratze lineal maximoa izango da zehaztutako
gainazal-desbideratzea bidez uneko amaraun segmentuaren (ertzaren) luzera.
</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="102"/>
      <source>Relative surface deviation</source>
      <translation>Gainazalaren desbideratze erlatiboa</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="109"/>
      <source>Mesh will get face colors of the object</source>
      <translation>Amaraunak objektuaren aurpegi-koloreak hartuko ditu</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="112"/>
      <source>Apply face colors to mesh</source>
      <translation>Aplikatu aurpegi-koloreak amaraunari</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="119"/>
      <source>Mesh segments will be grouped according to the color of the object faces.
These groups will be exported for mesh output formats supporting
this feature (e.g. the format OBJ).</source>
      <translation>Amaraun segmentuak objektu-aurpegien kolorearen arabera taldekatuko dira.
Talde horiek ezaugarri hau onartzen duten irteera-formatuetara esportatuko dira
(adibidez, OBJ formatua).</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="124"/>
      <source>Define segments by face colors</source>
      <translation>Definitu segmentuak aurpegi-kolorearen arabera</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="145"/>
      <source>Mefisto</source>
      <translation>Mefisto</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="148"/>
      <source>Use the Mefisto mesher</source>
      <translation>Erabili Mefisto amaraun-sortzailea</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="156"/>
      <source>Maximum edge length:</source>
      <translation>Ertz-luzera maximoa:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="162"/>
      <source>If this number is smaller the mesh becomes finer.
The smallest value is 0.</source>
      <translation>Zenbaki hau txikiagoa bada, amarauna meheagoa bihurtzen da.
Baliorik txikiena 0 da.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="183"/>
      <source>Estimate</source>
      <translation>Zenbatetsi</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="206"/>
      <source>Netgen</source>
      <translation>Netgen</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="209"/>
      <source>Use the Netgen mesher</source>
      <translation>Erabili Netgen amaraun-sortzailea</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="217"/>
      <source>Fineness:</source>
      <translation>Fintasuna:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="234"/>
      <source>Very coarse</source>
      <translation>Oso latza</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="239"/>
      <source>Coarse</source>
      <translation>Latza</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="244"/>
      <source>Moderate</source>
      <translation>Ertaina</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="249"/>
      <source>Fine</source>
      <translation>Fina</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="254"/>
      <source>Very fine</source>
      <translation>Oso xehea</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="259"/>
      <source>User defined</source>
      <translation>Erabiltzaileak definitutakoa</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="269"/>
      <source>Mesh size grading:</source>
      <translation>Amaraun-tamainaren graduazioa:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="279"/>
      <source>If this parameter is smaller, the mesh becomes finer.
A value in the range of 0.1-1.</source>
      <translation>Parametro hau txikiagoa bada, amarauna meheagoa bihurtzen da.
0.1-1 barrutiko balio bat.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="302"/>
      <source>Elements per edge:</source>
      <translation>Elementuak ertz bakoitzeko:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="312"/>
      <location filename="../../Tessellation.ui" line="345"/>
      <source>If this parameter is larger, the mesh becomes finer.
A value in the range of 0.2-10.</source>
      <translation>Parametro hau handiagoa bada, amarauna meheagoa bihurtzen da.
0.2-10 barrutiko balio bat.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="335"/>
      <source>Elements per curvature radius:</source>
      <translation>Elementu kopurua kurbadura-erradioko:</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="370"/>
      <source>Whether optimization of surface shape will be done</source>
      <translation>Gainazal-formaren optimizazioa egingo den ala ez</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="373"/>
      <source>Optimize surface</source>
      <translation>Optimizatu gainazala</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="383"/>
      <source>Whether second order elements will be generated</source>
      <translation>Bigarren mailako elementuak sortuko diren ala ez</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="386"/>
      <source>Second order elements</source>
      <translation>Bigarren ordenako elementuak</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="393"/>
      <source>Whether meshes will be arranged preferably using quadrilateral faces</source>
      <translation>Amaraunak ahal bada lau aldeko aurpegiak erabilita antolatuko diren ala ez</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="396"/>
      <source>Quad dominated</source>
      <translation>Karratuen mendekoa</translation>
    </message>
    <message>
      <location filename="../../Tessellation.ui" line="422"/>
      <source>Leave panel open</source>
      <translation>Utzi panela irekita</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="61"/>
      <source>Gmsh</source>
      <translation>Gmsh</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="225"/>
      <location filename="../../Tessellation.cpp" line="231"/>
      <source>No active document</source>
      <translation>Ez dago dokumentu aktiborik</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="259"/>
      <source>You have selected a body without tip.
Either set the tip of the body or select a different shape, please.</source>
      <translation>Puntarik ez duen gorputz bat hautatu duzu.
Ezarri gorputzaren punta edo hautatu beste forma bat.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="263"/>
      <source>You have selected a shape without faces.
Select a different shape, please.</source>
      <translation>Aurpegirik ez duen forma bat hautatu duzu.
Hautatu beste forma bat.</translation>
    </message>
    <message>
      <location filename="../../Tessellation.cpp" line="267"/>
      <source>Select a shape for meshing, first.</source>
      <translation>Hasteko, hautatu forma bat amarauna sortzeko.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_Section</name>
    <message>
      <location filename="../../Command.cpp" line="198"/>
      <source>Select plane</source>
      <translation>Hautatu planoa</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="199"/>
      <source>Please select a plane at which you section the mesh.</source>
      <translation>Hautatu amarauna ebakitzeko erabiliko den planoa.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_TrimByPlane</name>
    <message>
      <location filename="../../Command.cpp" line="95"/>
      <source>Select plane</source>
      <translation>Hautatu planoa</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="96"/>
      <source>Please select a plane at which you trim the mesh.</source>
      <translation>Hautatu amarauna muxarratzeko erabiliko den planoa.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Trim by plane</source>
      <translation>Ebaki planoaren bidez</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Select the side you want to keep.</source>
      <translation>Hautatu mantendu nahi duzun aldea.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Below</source>
      <translation>Azpian</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="105"/>
      <source>Above</source>
      <translation>Gainean</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="106"/>
      <source>Split</source>
      <translation>Zatitu</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="36"/>
      <source>MeshPart</source>
      <translation>Amaraun-pieza</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatMesh</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="47"/>
      <source>Unwrap Mesh</source>
      <translation>Desestali amarauna</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="50"/>
      <source>Find a flat representation of a mesh.</source>
      <translation>Aurkitu amaraunaren irudikapen laua.</translation>
    </message>
  </context>
  <context>
    <name>MeshPart_CreateFlatFace</name>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="79"/>
      <source>Unwrap Face</source>
      <translation>Desestali aurpegia</translation>
    </message>
    <message>
      <location filename="../../MeshFlatteningCommand.py" line="82"/>
      <source>Find a flat representation of a face.</source>
      <translation>Aurkitu aurpegiaren irudikapen laua.</translation>
    </message>
  </context>
</TS>
